package router

import (
	"net/http"

	"github.com/gin-contrib/pprof"
	"github.com/gin-gonic/gin"

	"demo/internal/router/mid"
	"demo/internal/service"
)

type Web struct {
	Common  *mid.Common
	Jwt     *mid.Jwt
	Greeter *service.GreeterService
	Report  *service.ReportService
}

func (p *Web) RouterInit(engine *gin.Engine) {
	engine.Use(p.Common.SetRequestId, p.Common.PassMethods)
	engine.NoRoute(func(c *gin.Context) {
		c.JSON(http.StatusNotFound, gin.H{"code": "404", "msg": "PageNo not found"})
	})
	// add pprof to look at the heap,a 30-second CPU and so on profile
	// eg: go tool pprof http://localhost:8000/api/pprof/profile
	pprof.Register(engine, "/api/pprof")
	// add api
	engine.GET("/hello/:name", p.Greeter.SayHello)
	api := engine.Group("/api", p.Jwt.CheckToken)
	{
		api.POST("/report", p.Report.ListCampaignData)
	}
}
